@@ -2,7 +2,7 @@
  * application: Single-instance managing application and single-instance
  *              objects like window manager and so on.
  * 
- * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,14 +66,6 @@
 
 
 /* Define this class in GObject system */
-G_DEFINE_TYPE(XfdashboardApplication,
-				xfdashboard_application,
-				G_TYPE_APPLICATION)
-
-/* Private structure - access only by public API if needed */
-#define XFDASHBOARD_APPLICATION_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((obj), XFDASHBOARD_TYPE_APPLICATION, XfdashboardApplicationPrivate))
-
 struct _XfdashboardApplicationPrivate
 {
 	/* Properties related */
@@ -107,6 +99,10 @@ struct _XfdashboardApplicationPrivate
 	XfdashboardWindowTrackerBackend		*windowTrackerBackend;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(XfdashboardApplication,
+							xfdashboard_application,
+							G_TYPE_APPLICATION)
+
 /* Properties */
 enum
 {
@@ -649,6 +645,8 @@ static gint _xfdashboard_application_handle_command_line_arguments(XfdashboardAp
 										{ "images", XFDASHBOARD_DEBUG_IMAGES },
 										{ "windows", XFDASHBOARD_DEBUG_WINDOWS },
 										{ "window-tracker", XFDASHBOARD_DEBUG_WINDOWS },
+										{ "animation", XFDASHBOARD_DEBUG_ANIMATION },
+										{ "animations", XFDASHBOARD_DEBUG_ANIMATION },
 									};
 
 		/* Parse debug flags */
@@ -1195,9 +1193,6 @@ static void xfdashboard_application_class_init(XfdashboardApplicationClass *klas
 	gobjectClass->set_property=_xfdashboard_application_set_property;
 	gobjectClass->get_property=_xfdashboard_application_get_property;
 
-	/* Set up private structure */
-	g_type_class_add_private(klass, sizeof(XfdashboardApplicationPrivate));
-
 	/* Define properties */
 	/**
 	 * XfdashboardApplication:is-daemonized:
@@ -1480,7 +1475,7 @@ static void xfdashboard_application_init(XfdashboardApplication *self)
 	XfdashboardApplicationPrivate	*priv;
 	GSimpleAction					*action;
 
-	priv=self->priv=XFDASHBOARD_APPLICATION_GET_PRIVATE(self);
+	priv=self->priv=xfdashboard_application_get_instance_private(self);
 
 	/* Set default values */
 	priv->isDaemon=FALSE;
