@@ -2,7 +2,7 @@
  * desktop-app-info: A GDesktopAppInfo like object for garcon menu
  *                   items implementing and supporting GAppInfo
  * 
- * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #error "Only <libxfdashboard/libxfdashboard.h> can be included directly."
 #endif
 
+#include <libxfdashboard/desktop-app-info-action.h>
 #include <garcon/garcon.h>
 
 G_BEGIN_DECLS
@@ -78,6 +79,18 @@ gboolean xfdashboard_desktop_app_info_is_valid(XfdashboardDesktopAppInfo *self);
 GFile* xfdashboard_desktop_app_info_get_file(XfdashboardDesktopAppInfo *self);
 gboolean xfdashboard_desktop_app_info_reload(XfdashboardDesktopAppInfo *self);
 
+GList* xfdashboard_desktop_app_info_get_actions(XfdashboardDesktopAppInfo *self);
+gboolean xfdashboard_desktop_app_info_launch_action(XfdashboardDesktopAppInfo *self,
+													XfdashboardDesktopAppInfoAction *inAction,
+													GAppLaunchContext *inContext,
+													GError **outError);
+gboolean xfdashboard_desktop_app_info_launch_action_by_name(XfdashboardDesktopAppInfo *self,
+															const gchar *inActionName,
+															GAppLaunchContext *inContext,
+															GError **outError);
+
+GList* xfdashboard_desktop_app_info_get_keywords(XfdashboardDesktopAppInfo *self);
+
 G_END_DECLS
 
 #endif	/* __LIBXFDASHBOARD_DESKTOP_APP_INFO__ */
