@@ -2,7 +2,7 @@
  * focus-manager: Single-instance managing focusable actors
  *                for keyboard navigation
  * 
- * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,14 +39,6 @@
 
 
 /* Define this class in GObject system */
-G_DEFINE_TYPE(XfdashboardFocusManager,
-				xfdashboard_focus_manager,
-				G_TYPE_OBJECT)
-
-/* Private structure - access only by public API if needed */
-#define XFDASHBOARD_FOCUS_MANAGER_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((obj), XFDASHBOARD_TYPE_FOCUS_MANAGER, XfdashboardFocusManagerPrivate))
-
 struct _XfdashboardFocusManagerPrivate
 {
 	/* Instance related */
@@ -54,6 +46,10 @@ struct _XfdashboardFocusManagerPrivate
 	XfdashboardFocusable	*currentFocus;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(XfdashboardFocusManager,
+							xfdashboard_focus_manager,
+							G_TYPE_OBJECT)
+
 /* Signals */
 enum
 {
@@ -327,6 +323,26 @@ static gboolean _xfdashboard_focus_manager_move_focus_previous(XfdashboardFocusM
 
 /* IMPLEMENTATION: GObject */
 
+/* Construct this object */
+static GObject* _xfdashboard_focus_manager_constructor(GType inType,
+														guint inNumberConstructParams,
+														GObjectConstructParam *inConstructParams)
+{
+	GObject									*object;
+
+	if(!_xfdashboard_focus_manager)
+	{
+		object=G_OBJECT_CLASS(xfdashboard_focus_manager_parent_class)->constructor(inType, inNumberConstructParams, inConstructParams);
+		_xfdashboard_focus_manager=XFDASHBOARD_FOCUS_MANAGER(object);
+	}
+		else
+		{
+			object=g_object_ref(G_OBJECT(_xfdashboard_focus_manager));
+		}
+
+	return(object);
+}
+
 /* Dispose this object */
 static void _xfdashboard_focus_manager_dispose_unregister_focusable(gpointer inData, gpointer inUserData)
 {
@@ -366,13 +382,24 @@ static void _xfdashboard_focus_manager_dispose(GObject *inObject)
 		priv->registeredFocusables=NULL;
 	}
 
-	/* Unset singleton */
-	if(G_LIKELY(G_OBJECT(_xfdashboard_focus_manager)==inObject)) _xfdashboard_focus_manager=NULL;
-
 	/* Call parent's class dispose method */
 	G_OBJECT_CLASS(xfdashboard_focus_manager_parent_class)->dispose(inObject);
 }
 
+/* Finalize this object */
+static void _xfdashboard_focus_manager_finalize(GObject *inObject)
+{
+	/* Release allocated resources finally, e.g. unset singleton */
+	if(G_LIKELY(G_OBJECT(_xfdashboard_focus_manager)==inObject))
+	{
+		_xfdashboard_focus_manager=NULL;
+	}
+
+	/* Call parent's class dispose method */
+	G_OBJECT_CLASS(xfdashboard_focus_manager_parent_class)->finalize(inObject);
+}
+
+
 /* Class initialization
  * Override functions in parent classes and define properties
  * and signals
@@ -382,16 +409,15 @@ static void xfdashboard_focus_manager_class_init(XfdashboardFocusManagerClass *k
 	GObjectClass		*gobjectClass=G_OBJECT_CLASS(klass);
 
 	/* Override functions */
+	gobjectClass->constructor=_xfdashboard_focus_manager_constructor;
 	gobjectClass->dispose=_xfdashboard_focus_manager_dispose;
+	gobjectClass->finalize=_xfdashboard_focus_manager_finalize;
 
 	klass->focus_move_first=_xfdashboard_focus_manager_move_focus_first;
 	klass->focus_move_last=_xfdashboard_focus_manager_move_focus_last;
 	klass->focus_move_next=_xfdashboard_focus_manager_move_focus_next;
 	klass->focus_move_previous=_xfdashboard_focus_manager_move_focus_previous;
 
-	/* Set up private structure */
-	g_type_class_add_private(klass, sizeof(XfdashboardFocusManagerPrivate));
-
 	/* Define signals */
 	XfdashboardFocusManagerSignals[SIGNAL_REGISTERED]=
 		g_signal_new("registered",
@@ -494,7 +520,7 @@ static void xfdashboard_focus_manager_init(XfdashboardFocusManager *self)
 {
 	XfdashboardFocusManagerPrivate	*priv;
 
-	priv=self->priv=XFDASHBOARD_FOCUS_MANAGER_GET_PRIVATE(self);
+	priv=self->priv=xfdashboard_focus_manager_get_instance_private(self);
 
 	/* Set default values */
 	priv->registeredFocusables=NULL;
@@ -506,13 +532,10 @@ static void xfdashboard_focus_manager_init(XfdashboardFocusManager *self)
 /* Get single instance of manager */
 XfdashboardFocusManager* xfdashboard_focus_manager_get_default(void)
 {
-	if(G_UNLIKELY(_xfdashboard_focus_manager==NULL))
-	{
-		_xfdashboard_focus_manager=g_object_new(XFDASHBOARD_TYPE_FOCUS_MANAGER, NULL);
-	}
-		else g_object_ref(_xfdashboard_focus_manager);
+	GObject									*singleton;
 
-	return(_xfdashboard_focus_manager);
+	singleton=g_object_new(XFDASHBOARD_TYPE_FOCUS_MANAGER, NULL);
+	return(XFDASHBOARD_FOCUS_MANAGER(singleton));
 }
 
 /* Register a focusable actor */
