@@ -2,7 +2,7 @@
  * popup-menu: A pop-up menu with menu items performing an action when an menu
  *             item was clicked
  * 
- * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,15 +69,6 @@
 /* Define this class in GObject system */
 static void _xfdashboard_popup_menu_focusable_iface_init(XfdashboardFocusableInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE(XfdashboardPopupMenu,
-						xfdashboard_popup_menu,
-						XFDASHBOARD_TYPE_BACKGROUND,
-						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_FOCUSABLE, _xfdashboard_popup_menu_focusable_iface_init));
-
-/* Private structure - access only by public API if needed */
-#define XFDASHBOARD_POPUP_MENU_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((obj), XFDASHBOARD_TYPE_POPUP_MENU, XfdashboardPopupMenuPrivate))
-
 struct _XfdashboardPopupMenuPrivate
 {
 	/* Properties related */
@@ -104,8 +95,16 @@ struct _XfdashboardPopupMenuPrivate
 	guint							capturedEventSignalID;
 
 	guint							sourceDestroySignalID;
+
+	guint							suspendSignalID;
 };
 
+G_DEFINE_TYPE_WITH_CODE(XfdashboardPopupMenu,
+						xfdashboard_popup_menu,
+						XFDASHBOARD_TYPE_BACKGROUND,
+						G_ADD_PRIVATE(XfdashboardPopupMenu)
+						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_FOCUSABLE, _xfdashboard_popup_menu_focusable_iface_init));
+
 /* Properties */
 enum
 {
@@ -146,6 +145,37 @@ static guint XfdashboardPopupMenuSignals[SIGNAL_LAST]={ 0, };
 
 /* IMPLEMENTATION: Private variables and methods */
 
+/* Suspension state of application changed */
+static void _xfdashboard_popup_menu_on_application_suspended_changed(XfdashboardPopupMenu *self,
+																		GParamSpec *inSpec,
+																		gpointer inUserData)
+{
+	XfdashboardPopupMenuPrivate		*priv;
+	XfdashboardApplication			*application;
+	gboolean						isSuspended;
+
+	g_return_if_fail(XFDASHBOARD_IS_POPUP_MENU(self));
+	g_return_if_fail(XFDASHBOARD_IS_APPLICATION(inUserData));
+
+	priv=self->priv;
+	application=XFDASHBOARD_APPLICATION(inUserData);
+
+	/* Get application suspend state */
+	isSuspended=xfdashboard_application_is_suspended(application);
+
+	/* If application is suspended then cancel pop-up menu */
+	if(isSuspended)
+	{
+		XFDASHBOARD_DEBUG(self, ACTOR,
+							"Cancel active pop-up menu '%s' for source %s@%p because application was suspended",
+							xfdashboard_popup_menu_get_title(self),
+							priv->source ? G_OBJECT_TYPE_NAME(priv->source) : "<nil>",
+							priv->source);
+
+		xfdashboard_popup_menu_cancel(self);
+	}
+}
+
 /* An event occured after a popup menu was activated so check if popup menu should
  * be cancelled because a button was pressed and release outside the popup menu.
  */
@@ -723,6 +753,12 @@ static void _xfdashboard_popup_menu_dispose(GObject *inObject)
 	xfdashboard_popup_menu_cancel(self);
 
 	/* Release our allocated variables */
+	if(priv->suspendSignalID)
+	{
+		g_signal_handler_disconnect(xfdashboard_application_get_default(), priv->suspendSignalID);
+		priv->suspendSignalID=0;
+	}
+
 	if(priv->capturedEventSignalID)
 	{
 		g_signal_handler_disconnect(priv->stage, priv->capturedEventSignalID);
@@ -895,9 +931,6 @@ static void xfdashboard_popup_menu_class_init(XfdashboardPopupMenuClass *klass)
 
 	clutterActorClass->allocate=_xfdashboard_popup_menu_allocate;
 
-	/* Set up private structure */
-	g_type_class_add_private(klass, sizeof(XfdashboardPopupMenuPrivate));
-
 	/* Define properties */
 	/**
 	 * XfdashboardPopupMenu:destroy-on-cancel:
@@ -1099,7 +1132,7 @@ static void xfdashboard_popup_menu_init(XfdashboardPopupMenu *self)
 	XfdashboardPopupMenuPrivate		*priv;
 	ClutterLayoutManager			*layout;
 
-	priv=self->priv=XFDASHBOARD_POPUP_MENU_GET_PRIVATE(self);
+	priv=self->priv=xfdashboard_popup_menu_get_instance_private(self);
 
 	/* Set up default values */
 	priv->destroyOnCancel=FALSE;
@@ -1116,6 +1149,7 @@ static void xfdashboard_popup_menu_init(XfdashboardPopupMenu *self)
 	priv->stage=NULL;
 	priv->capturedEventSignalID=0;
 	priv->sourceDestroySignalID=0;
+	priv->suspendSignalID=0;
 
 	/* This actor is react on events */
 	clutter_actor_set_reactive(CLUTTER_ACTOR(self), TRUE);
@@ -1155,6 +1189,12 @@ static void xfdashboard_popup_menu_init(XfdashboardPopupMenu *self)
 	/* Add popup menu to stage */
 	priv->stage=xfdashboard_application_get_stage(xfdashboard_application_get_default());
 	clutter_actor_insert_child_above(CLUTTER_ACTOR(priv->stage), CLUTTER_ACTOR(self), NULL);
+
+	/* Connect signal to get notified when application suspends to cancel pop-up menu */
+	priv->suspendSignalID=g_signal_connect_swapped(xfdashboard_application_get_default(),
+													"notify::is-suspended",
+													G_CALLBACK(_xfdashboard_popup_menu_on_application_suspended_changed),
+													self);
 }
 
 /* IMPLEMENTATION: Public API */
@@ -1827,6 +1867,9 @@ void xfdashboard_popup_menu_activate(XfdashboardPopupMenu *self)
 	pointerDevice=gdk_device_manager_get_client_pointer(deviceManager);
 #endif
 	gdk_device_get_position(pointerDevice, NULL, &pointerX, &pointerY);
+	XFDASHBOARD_DEBUG(self, ACTOR,
+						"Pointer is at position %d,%d",
+						pointerX, pointerY);
 
 	monitor=xfdashboard_window_tracker_get_monitor_by_position(priv->windowTracker, pointerX, pointerY);
 	if(!monitor)
