@@ -51,6 +51,7 @@ enum
 	SIGNAL_WORKSPACE_CHANGED,
 	SIGNAL_MONITOR_CHANGED,
 	SIGNAL_GEOMETRY_CHANGED,
+	SIGNAL_CLOSED,
 
 	SIGNAL_LAST
 };
@@ -219,10 +220,9 @@ static void xfdashboard_window_tracker_window_default_init(XfdashboardWindowTrac
 							G_STRUCT_OFFSET(XfdashboardWindowTrackerWindowInterface, state_changed),
 							NULL,
 							NULL,
-							_xfdashboard_marshal_VOID__FLAGS_FLAGS,
+							g_cclosure_marshal_VOID__FLAGS,
 							G_TYPE_NONE,
-							2,
-							XFDASHBOARD_TYPE_WINDOW_TRACKER_WINDOW_STATE,
+							1,
 							XFDASHBOARD_TYPE_WINDOW_TRACKER_WINDOW_STATE);
 
 		XfdashboardWindowTrackerWindowSignals[SIGNAL_ACTIONS_CHANGED]=
@@ -232,10 +232,9 @@ static void xfdashboard_window_tracker_window_default_init(XfdashboardWindowTrac
 							G_STRUCT_OFFSET(XfdashboardWindowTrackerWindowInterface, actions_changed),
 							NULL,
 							NULL,
-							_xfdashboard_marshal_VOID__FLAGS_FLAGS,
+							g_cclosure_marshal_VOID__FLAGS,
 							G_TYPE_NONE,
-							2,
-							XFDASHBOARD_TYPE_WINDOW_TRACKER_WINDOW_ACTION,
+							1,
 							XFDASHBOARD_TYPE_WINDOW_TRACKER_WINDOW_ACTION);
 
 		XfdashboardWindowTrackerWindowSignals[SIGNAL_ICON_CHANGED]=
@@ -284,6 +283,17 @@ static void xfdashboard_window_tracker_window_default_init(XfdashboardWindowTrac
 							G_TYPE_NONE,
 							0);
 
+		XfdashboardWindowTrackerWindowSignals[SIGNAL_CLOSED]=
+			g_signal_new("closed",
+							G_TYPE_FROM_INTERFACE(iface),
+							G_SIGNAL_RUN_LAST,
+							G_STRUCT_OFFSET(XfdashboardWindowTrackerWindowInterface, closed),
+							NULL,
+							NULL,
+							g_cclosure_marshal_VOID__VOID,
+							G_TYPE_NONE,
+							0);
+
 		/* Set flag that base initialization was done for this interface */
 		initialized=TRUE;
 	}
