@@ -45,22 +45,17 @@
 /* Define this class in GObject system */
 static void _xfdashboard_window_tracker_backend_x11_window_tracker_backend_iface_init(XfdashboardWindowTrackerBackendInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE(XfdashboardWindowTrackerBackendX11,
-						xfdashboard_window_tracker_backend_x11,
-						G_TYPE_OBJECT,
-						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_WINDOW_TRACKER_BACKEND, _xfdashboard_window_tracker_backend_x11_window_tracker_backend_iface_init))
-
-
-/* Private structure - access only by public API if needed */
-#define XFDASHBOARD_WINDOW_TRACKER_BACKEND_X11_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((obj), XFDASHBOARD_TYPE_WINDOW_TRACKER_BACKEND_X11, XfdashboardWindowTrackerBackendX11Private))
-
 struct _XfdashboardWindowTrackerBackendX11Private
 {
 	/* Instance related */
 	XfdashboardWindowTrackerX11		*windowTracker;
 };
 
+G_DEFINE_TYPE_WITH_CODE(XfdashboardWindowTrackerBackendX11,
+						xfdashboard_window_tracker_backend_x11,
+						G_TYPE_OBJECT,
+						G_ADD_PRIVATE(XfdashboardWindowTrackerBackendX11)
+						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_WINDOW_TRACKER_BACKEND, _xfdashboard_window_tracker_backend_x11_window_tracker_backend_iface_init))
 
 /* IMPLEMENTATION: Private variables and methods */
 
@@ -728,9 +723,6 @@ void xfdashboard_window_tracker_backend_x11_class_init(XfdashboardWindowTrackerB
 
 	/* Override functions */
 	gobjectClass->dispose=_xfdashboard_window_tracker_backend_x11_dispose;
-
-	/* Set up private structure */
-	g_type_class_add_private(klass, sizeof(XfdashboardWindowTrackerBackendX11Private));
 }
 
 /* Object initialization
@@ -740,7 +732,7 @@ void xfdashboard_window_tracker_backend_x11_init(XfdashboardWindowTrackerBackend
 {
 	XfdashboardWindowTrackerBackendX11Private		*priv;
 
-	priv=self->priv=XFDASHBOARD_WINDOW_TRACKER_BACKEND_X11_GET_PRIVATE(self);
+	priv=self->priv=xfdashboard_window_tracker_backend_x11_get_instance_private(self);
 
 	XFDASHBOARD_DEBUG(self, WINDOWS, "Initializing X11 window tracker backend");
 
