@@ -7,7 +7,7 @@
  *                 We only need to use #ifdefs in window tracker object
  *                 and nowhere else in the code.
  * 
- * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,15 +60,6 @@
 /* Define this class in GObject system */
 static void _xfdashboard_window_tracker_x11_window_tracker_iface_init(XfdashboardWindowTrackerInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE(XfdashboardWindowTrackerX11,
-						xfdashboard_window_tracker_x11,
-						G_TYPE_OBJECT,
-						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_WINDOW_TRACKER, _xfdashboard_window_tracker_x11_window_tracker_iface_init))
-
-/* Private structure - access only by public API if needed */
-#define XFDASHBOARD_WINDOW_TRACKER_X11_GET_PRIVATE(obj)                        \
-	(G_TYPE_INSTANCE_GET_PRIVATE((obj), XFDASHBOARD_TYPE_WINDOW_TRACKER_X11, XfdashboardWindowTrackerX11Private))
-
 struct _XfdashboardWindowTrackerX11Private
 {
 	/* Properties related */
@@ -97,6 +88,12 @@ struct _XfdashboardWindowTrackerX11Private
 #endif
 };
 
+G_DEFINE_TYPE_WITH_CODE(XfdashboardWindowTrackerX11,
+						xfdashboard_window_tracker_x11,
+						G_TYPE_OBJECT,
+						G_ADD_PRIVATE(XfdashboardWindowTrackerX11)
+						G_IMPLEMENT_INTERFACE(XFDASHBOARD_TYPE_WINDOW_TRACKER, _xfdashboard_window_tracker_x11_window_tracker_iface_init))
+
 /* Properties */
 enum
 {
@@ -428,43 +425,53 @@ static void _xfdashboard_window_tracker_x11_on_window_geometry_changed(Xfdashboa
 
 /* Action items of window has changed */
 static void _xfdashboard_window_tracker_x11_on_window_actions_changed(XfdashboardWindowTrackerX11 *self,
-																		XfdashboardWindowTrackerWindowAction inChangedMask,
-																		XfdashboardWindowTrackerWindowAction inNewValue,
+																		XfdashboardWindowTrackerWindowAction inOldActions,
 																		gpointer inUserData)
 {
-	XfdashboardWindowTrackerWindowX11	*window;
+	XfdashboardWindowTrackerWindowX11		*window;
+	XfdashboardWindowTrackerWindowAction	newActions;
+	XfdashboardWindowTrackerWindowAction	changedActions;
 
 	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER(self));
 	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW_X11(inUserData));
 
 	window=XFDASHBOARD_WINDOW_TRACKER_WINDOW_X11(inUserData);
 
-	/* Emit signal */
+	/* Debugging information */
+	newActions=xfdashboard_window_tracker_window_get_state(XFDASHBOARD_WINDOW_TRACKER_WINDOW(window));
+	changedActions=inOldActions ^ newActions;
 	XFDASHBOARD_DEBUG(self, WINDOWS,
-						"Window '%s' changed actions to %u with mask %u",
+						"Window '%s' changed actions from %u to %u with mask %u",
 						xfdashboard_window_tracker_window_get_name(XFDASHBOARD_WINDOW_TRACKER_WINDOW(window)),
-						inNewValue, inChangedMask);
+						inOldActions, newActions, changedActions);
+
+	/* Emit signal */
 	g_signal_emit_by_name(self, "window-actions-changed", window);
 }
 
 /* State of window has changed */
 static void _xfdashboard_window_tracker_x11_on_window_state_changed(XfdashboardWindowTrackerX11 *self,
-																	XfdashboardWindowTrackerWindowState inChangedMask,
-																	XfdashboardWindowTrackerWindowState inNewValue,
+																	XfdashboardWindowTrackerWindowState inOldState,
 																	gpointer inUserData)
 {
-	XfdashboardWindowTrackerWindowX11	*window;
+	XfdashboardWindowTrackerWindowX11		*window;
+	XfdashboardWindowTrackerWindowState		newState;
+	XfdashboardWindowTrackerWindowState		changedStates;
 
 	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER(self));
 	g_return_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_WINDOW_X11(inUserData));
 
 	window=XFDASHBOARD_WINDOW_TRACKER_WINDOW_X11(inUserData);
 
-	/* Emit signal */
+	/* Debugging information */
+	newState=xfdashboard_window_tracker_window_get_state(XFDASHBOARD_WINDOW_TRACKER_WINDOW(window));
+	changedStates=inOldState ^ newState;
 	XFDASHBOARD_DEBUG(self, WINDOWS,
-						"Window '%s' changed state to %u with mask %u",
+						"Window '%s' changed state from %u to %u with mask %u",
 						xfdashboard_window_tracker_window_get_name(XFDASHBOARD_WINDOW_TRACKER_WINDOW(window)),
-						inNewValue, inChangedMask);
+						inOldState, newState, changedStates);
+
+	/* Emit signal */
 	g_signal_emit_by_name(self, "window-state-changed", window);
 }
 
@@ -1800,9 +1807,6 @@ void xfdashboard_window_tracker_x11_class_init(XfdashboardWindowTrackerX11Class
 	gobjectClass->set_property=_xfdashboard_window_tracker_x11_set_property;
 	gobjectClass->get_property=_xfdashboard_window_tracker_x11_get_property;
 
-	/* Set up private structure */
-	g_type_class_add_private(klass, sizeof(XfdashboardWindowTrackerX11Private));
-
 	/* Define properties */
 	paramSpec=g_object_interface_find_property(trackerIface, "active-window");
 	XfdashboardWindowTrackerX11Properties[PROP_ACTIVE_WINDOW]=
@@ -1829,7 +1833,7 @@ void xfdashboard_window_tracker_x11_init(XfdashboardWindowTrackerX11 *self)
 {
 	XfdashboardWindowTrackerX11Private		*priv;
 
-	priv=self->priv=XFDASHBOARD_WINDOW_TRACKER_X11_GET_PRIVATE(self);
+	priv=self->priv=xfdashboard_window_tracker_x11_get_instance_private(self);
 
 	XFDASHBOARD_DEBUG(self, WINDOWS, "Initializing X11 window tracker");
 
