@@ -1,7 +1,7 @@
 /*
  * plugins: Plugin settings of application
  * 
- * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2019 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,14 +33,6 @@
 
 
 /* Define this class in GObject system */
-G_DEFINE_TYPE(XfdashboardSettingsPlugins,
-				xfdashboard_settings_plugins,
-				G_TYPE_OBJECT)
-
-/* Private structure - access only by public API if needed */
-#define XFDASHBOARD_SETTINGS_PLUGINS_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((obj), XFDASHBOARD_TYPE_SETTINGS_PLUGINS, XfdashboardSettingsPluginsPrivate))
-
 struct _XfdashboardSettingsPluginsPrivate
 {
 	/* Properties related */
@@ -66,6 +58,10 @@ struct _XfdashboardSettingsPluginsPrivate
 	GtkWidget		*widgetPluginPreferencesDialogTitle;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(XfdashboardSettingsPlugins,
+							xfdashboard_settings_plugins,
+							G_TYPE_OBJECT)
+
 /* Properties */
 enum
 {
@@ -674,7 +670,8 @@ static void _xfdashboard_settings_plugins_enabled_plugins_changed_by_xfconf(Xfda
 /* Sorting function for theme list's model */
 static gint _xfdashboard_settings_plugins_sort_plugins_list_model(GtkTreeModel *inModel,
 																	GtkTreeIter *inLeft,
-																	GtkTreeIter *inRight)
+																	GtkTreeIter *inRight,
+																	gpointer inUserData)
 {
 	gchar	*leftName;
 	gchar	*rightName;
@@ -1175,9 +1172,6 @@ static void xfdashboard_settings_plugins_class_init(XfdashboardSettingsPluginsCl
 	gobjectClass->set_property=_xfdashboard_settings_plugins_set_property;
 	gobjectClass->get_property=_xfdashboard_settings_plugins_get_property;
 
-	/* Set up private structure */
-	g_type_class_add_private(klass, sizeof(XfdashboardSettingsPluginsPrivate));
-
 	/* Define properties */
 	XfdashboardSettingsPluginsProperties[PROP_BUILDER]=
 		g_param_spec_object("builder",
@@ -1196,7 +1190,7 @@ static void xfdashboard_settings_plugins_init(XfdashboardSettingsPlugins *self)
 {
 	XfdashboardSettingsPluginsPrivate	*priv;
 
-	priv=self->priv=XFDASHBOARD_SETTINGS_PLUGINS_GET_PRIVATE(self);
+	priv=self->priv=xfdashboard_settings_plugins_get_instance_private(self);
 
 	/* Set default values */
 	priv->builder=NULL;
